==> kubernetes-model-apiextensions-5.2.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionVersionBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CustomResourceDefinitionVersionBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionBuilder> {

    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionFluent<?> fluent;
    Boolean validationEnabled;

    public CustomResourceDefinitionVersionBuilder() {
        this(true);
    }

    public CustomResourceDefinitionVersionBuilder(Boolean validationEnabled) {
        this(new CustomResourceDefinitionVersion(), validationEnabled);
    }

    public CustomResourceDefinitionVersionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionFluent<?> fluent) {
        this(fluent, true);
    }

    public CustomResourceDefinitionVersionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new CustomResourceDefinitionVersion(), validationEnabled);
    }

    public CustomResourceDefinitionVersionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion instance) {
        this(fluent, instance, true);
    }

    public CustomResourceDefinitionVersionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAdditionalPrinterColumns(instance.getAdditionalPrinterColumns()); 
        fluent.withDeprecated(instance.getDeprecated()); 
        fluent.withDeprecationWarning(instance.getDeprecationWarning()); 
        fluent.withName(instance.getName()); 
        fluent.withSchema(instance.getSchema()); 
        fluent.withServed(instance.getServed()); 
        fluent.withStorage(instance.getStorage()); 
        fluent.withSubresources(instance.getSubresources()); 
        this.validationEnabled = validationEnabled; 
    }

    public CustomResourceDefinitionVersionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion instance) {
        this(instance,true);
    }

    public CustomResourceDefinitionVersionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAdditionalPrinterColumns(instance.getAdditionalPrinterColumns()); 
        this.withDeprecated(instance.getDeprecated()); 
        this.withDeprecationWarning(instance.getDeprecationWarning()); 
        this.withName(instance.getName()); 
        this.withSchema(instance.getSchema()); 
        this.withServed(instance.getServed()); 
        this.withStorage(instance.getStorage()); 
        this.withSubresources(instance.getSubresources()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion build() {
        CustomResourceDefinitionVersion buildable = new CustomResourceDefinitionVersion(fluent.getAdditionalPrinterColumns(),fluent.isDeprecated(),fluent.getDeprecationWarning(),fluent.getName(),fluent.getSchema(),fluent.isServed(),fluent.isStorage(),fluent.getSubresources());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CustomResourceDefinitionVersionBuilder that = (CustomResourceDefinitionVersionBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-apiextensions-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionVersionBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CustomResourceDefinitionVersionBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionBuilder> {

    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionFluent<?> fluent;
    Boolean validationEnabled;

    public CustomResourceDefinitionVersionBuilder() {
        this(true);
    }

    public CustomResourceDefinitionVersionBuilder(Boolean validationEnabled) {
        this(new CustomResourceDefinitionVersion(), validationEnabled);
    }

    public CustomResourceDefinitionVersionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionFluent<?> fluent) {
        this(fluent, true);
    }

    public CustomResourceDefinitionVersionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new CustomResourceDefinitionVersion(), validationEnabled);
    }

    public CustomResourceDefinitionVersionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion instance) {
        this(fluent, instance, true);
    }

    public CustomResourceDefinitionVersionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAdditionalPrinterColumns(instance.getAdditionalPrinterColumns()); 
        fluent.withDeprecated(instance.getDeprecated()); 
        fluent.withDeprecationWarning(instance.getDeprecationWarning()); 
        fluent.withName(instance.getName()); 
        fluent.withSchema(instance.getSchema()); 
        fluent.withServed(instance.getServed()); 
        fluent.withStorage(instance.getStorage()); 
        fluent.withSubresources(instance.getSubresources()); 
        this.validationEnabled = validationEnabled; 
    }

    public CustomResourceDefinitionVersionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion instance) {
        this(instance,true);
    }

    public CustomResourceDefinitionVersionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAdditionalPrinterColumns(instance.getAdditionalPrinterColumns()); 
        this.withDeprecated(instance.getDeprecated()); 
        this.withDeprecationWarning(instance.getDeprecationWarning()); 
        this.withName(instance.getName()); 
        this.withSchema(instance.getSchema()); 
        this.withServed(instance.getServed()); 
        this.withStorage(instance.getStorage()); 
        this.withSubresources(instance.getSubresources()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion build() {
        CustomResourceDefinitionVersion buildable = new CustomResourceDefinitionVersion(fluent.getAdditionalPrinterColumns(),fluent.getDeprecated(),fluent.getDeprecationWarning(),fluent.getName(),fluent.getSchema(),fluent.getServed(),fluent.getStorage(),fluent.getSubresources());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CustomResourceDefinitionVersionBuilder that = (CustomResourceDefinitionVersionBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
